# Literature

## Abyzov-2011

Abyzov,A. et al. (2011) CNVnator: an approach to discover, genotype,
    and characterize typical and atypical CNVs from family and
    population genome sequencing. Genome Res., 21, 974--984.

## Abyzov-2015

Abyzov,A. et al. (2015) Analysis of deletion breakpoints from 1,092
    humans reveals details of mutation mechanisms. Nat. Commun.,
    6, 7256.

## Chen-2009

Chen,K. et al. (2009) BreakDancer: an algorithm for high-resolution
    mapping of genomic structural variation. Nat. Methods, 6, 677--681.

## Chen-2016

Chen,X. et al. (2016) Manta: rapid detection of structural variants
    and indels for germline and cancer sequencing applications.
    Bioinformatics, 32, 1220--1222.

## Haas-2017

Haas,B et al. (2017) STAR-Fusion: Fast and Accurate Fusion
    Transcript Detection from RNA-Seq. doi:
    <https://doi.org/10.1101/120295>

## Iyer-2011

Iyer,M.K. et al. (2011) ChimeraScan: a tool for identifying chimeric
    transcription in sequencing data. Bioinformatics, 27, 2903--2904.

## MacDonald-2014

MacDonald,J.R. et al. (2014) The Database of Genomic Variants: a
    curated collection of structural variation in the human genome.
    Nucleic Acids Res., 42, D986--92.

## McPherson-2011

McPherson,A. et al. (2011) deFuse: an algorithm for gene fusion
    discovery in tumor RNA-Seq data. PLoS Comput. Biol., 7, e1001138.

## Rausch-2012

Rausch,T. et al. (2012) DELLY: structural variant discovery by
    integrated paired-end and split-read analysis. Bioinformatics, 28,
    i333--i339.

## Robertson-2010

Robertson,G. et al. (2010) De novo assembly and analysis of RNA-seq
    data. Nat. Methods, 7, 909--912.

## Saunders-2012

Saunders,C.T. et al. (2012) Strelka: accurate somatic small-variant
    calling from sequenced tumor--normal sample pairs. Bioinformatics,
    28, 1811--1817.

## Uhrig-2021

Uhrig,S. et al. (2021) Accurate and efficient detection of gene
    fusions from RNA sequencing data. Genome Res., 31, 448--460.

## Yates-2016

Yates,A. et al. (2016) Ensembl 2016. Nucleic Acids Res., 44,
    D710--D716.

## Ye-2009

Ye,K. et al. (2009) Pindel: a pattern growth approach to detect
    break points of large deletions and medium sized insertions from
    paired-end short reads. Bioinformatics, 25, 2865--2871.

## den-Dunnen-2016

den Dunnen,J.T. et al. (2016) HGVS Recommendations for the
    Description of Sequence Variants: 2016 Update. Hum. Mutat., 37,
    564--569.
